

class DatabaseConnector():
    '''

    '''

    def __init__(self, client, databaseConnectorId=None, service=None, name=None, createdAt=None, status=None, auth=None):
        self.client = client
        self.id = databaseConnectorId
        self.database_connector_id = databaseConnectorId
        self.service = service
        self.name = name
        self.created_at = createdAt
        self.status = status
        self.auth = auth

    def __repr__(self):
        return f"DatabaseConnector(database_connector_id={repr(self.database_connector_id)}, service={repr(self.service)}, name={repr(self.name)}, created_at={repr(self.created_at)}, status={repr(self.status)}, auth={repr(self.auth)})"

    def __eq__(self, other):
        return self.__class__ == other.__class__ and self.id == other.id

    def to_dict(self):
        return {'database_connector_id': self.database_connector_id, 'service': self.service, 'name': self.name, 'created_at': self.created_at, 'status': self.status, 'auth': self.auth}

    def list_objects(self):
        return self.client.list_database_connector_objects(self.database_connector_id)

    def get_object_schema(self, object_name=None):
        return self.client.get_database_connector_object_schema(self.database_connector_id, object_name)

    def rename(self, name):
        return self.client.rename_database_connector(self.database_connector_id, name)

    def verify(self):
        return self.client.verify_database_connector(self.database_connector_id)

    def remove(self):
        return self.client.remove_database_connector(self.database_connector_id)





class BatchDataset():
    '''

    '''

    def __init__(self, client, datasetId=None, status=None, uploaded=None, datasetType=None):
        self.client = client
        self.id = None
        self.dataset_id = datasetId
        self.status = status
        self.uploaded = uploaded
        self.dataset_type = datasetType

    def __repr__(self):
        return f"BatchDataset(dataset_id={repr(self.dataset_id)}, status={repr(self.status)}, uploaded={repr(self.uploaded)}, dataset_type={repr(self.dataset_type)})"

    def __eq__(self, other):
        return self.__class__ == other.__class__ and self.id == other.id

    def to_dict(self):
        return {'dataset_id': self.dataset_id, 'status': self.status, 'uploaded': self.uploaded, 'dataset_type': self.dataset_type}





class Schema():
    '''

    '''

    def __init__(self, client, name=None, columnMapping=None, columnDataType=None, custom=None, sql=None):
        self.client = client
        self.id = None
        self.name = name
        self.column_mapping = columnMapping
        self.column_data_type = columnDataType
        self.custom = custom
        self.sql = sql

    def __repr__(self):
        return f"Schema(name={repr(self.name)}, column_mapping={repr(self.column_mapping)}, column_data_type={repr(self.column_data_type)}, custom={repr(self.custom)}, sql={repr(self.sql)})"

    def __eq__(self, other):
        return self.__class__ == other.__class__ and self.id == other.id

    def to_dict(self):
        return {'name': self.name, 'column_mapping': self.column_mapping, 'column_data_type': self.column_data_type, 'custom': self.custom, 'sql': self.sql}





class ProjectValidation():
    '''

    '''

    def __init__(self, client, valid=None, datasetErrors=None, columnHints=None):
        self.client = client
        self.id = None
        self.valid = valid
        self.dataset_errors = datasetErrors
        self.column_hints = columnHints

    def __repr__(self):
        return f"ProjectValidation(valid={repr(self.valid)}, dataset_errors={repr(self.dataset_errors)}, column_hints={repr(self.column_hints)})"

    def __eq__(self, other):
        return self.__class__ == other.__class__ and self.id == other.id

    def to_dict(self):
        return {'valid': self.valid, 'dataset_errors': self.dataset_errors, 'column_hints': self.column_hints}





class DataFilter():
    '''

    '''

    def __init__(self, client, sql=None, type=None):
        self.client = client
        self.id = None
        self.sql = sql
        self.type = type

    def __repr__(self):
        return f"DataFilter(sql={repr(self.sql)}, type={repr(self.type)})"

    def __eq__(self, other):
        return self.__class__ == other.__class__ and self.id == other.id

    def to_dict(self):
        return {'sql': self.sql, 'type': self.type}



from .dataset_version import DatasetVersion


class Dataset():
    '''

    '''

    def __init__(self, client, datasetId=None, name=None, sourceType=None, dataSource=None, createdAt=None, refreshSchedules=None, ignoreBefore=None, ephemeral=None, lookbackDays=None, databaseConnectorId=None, databaseConnectorConfig=None, latestDatasetVersion={}):
        self.client = client
        self.id = datasetId
        self.dataset_id = datasetId
        self.name = name
        self.source_type = sourceType
        self.data_source = dataSource
        self.created_at = createdAt
        self.refresh_schedules = refreshSchedules
        self.ignore_before = ignoreBefore
        self.ephemeral = ephemeral
        self.lookback_days = lookbackDays
        self.database_connector_id = databaseConnectorId
        self.database_connector_config = databaseConnectorConfig
        self.latest_dataset_version = client._build_class(
            DatasetVersion, latestDatasetVersion)

    def __repr__(self):
        return f"Dataset(dataset_id={repr(self.dataset_id)}, name={repr(self.name)}, source_type={repr(self.source_type)}, data_source={repr(self.data_source)}, created_at={repr(self.created_at)}, refresh_schedules={repr(self.refresh_schedules)}, ignore_before={repr(self.ignore_before)}, ephemeral={repr(self.ephemeral)}, lookback_days={repr(self.lookback_days)}, database_connector_id={repr(self.database_connector_id)}, database_connector_config={repr(self.database_connector_config)}, latest_dataset_version={repr(self.latest_dataset_version)})"

    def __eq__(self, other):
        return self.__class__ == other.__class__ and self.id == other.id

    def to_dict(self):
        return {'dataset_id': self.dataset_id, 'name': self.name, 'source_type': self.source_type, 'data_source': self.data_source, 'created_at': self.created_at, 'refresh_schedules': self.refresh_schedules, 'ignore_before': self.ignore_before, 'ephemeral': self.ephemeral, 'lookback_days': self.lookback_days, 'database_connector_id': self.database_connector_id, 'database_connector_config': self.database_connector_config, 'latest_dataset_version': self.latest_dataset_version.to_dict() if self.latest_dataset_version else None}

    def create_version(self, location=None, file_format=None):
        return self.client.create_dataset_version(self.dataset_id, location, file_format)

    def create_version_from_local_file(self, file_format=None):
        return self.client.create_dataset_version_from_local_file(self.dataset_id, file_format)

    def create_version_from_database_connector(self, object_name=None, columns=None, query_arguments=None):
        return self.client.create_dataset_version_from_database_connector(self.dataset_id, object_name, columns, query_arguments)

    def snapshot_streaming_data(self):
        return self.client.snapshot_streaming_data(self.dataset_id)

    def set_ephemeral(self, ephemeral=None):
        return self.client.set_ephemeral(self.dataset_id, ephemeral)

    def set_ignore_before(self, timestamp=None):
        return self.client.set_ignore_before(self.dataset_id, timestamp)

    def set_lookback_days(self, lookback_days=None):
        return self.client.set_lookback_days(self.dataset_id, lookback_days)

    def refresh(self):
        self = self.describe()
        return self

    def describe(self):
        return self.client.describe_dataset(self.dataset_id)

    def list_versions(self):
        return self.client.list_dataset_versions(self.dataset_id)

    def attach_to_project(self, project_id, dataset_type):
        return self.client.attach_dataset_to_project(self.dataset_id, project_id, dataset_type)

    def remove_from_project(self, project_id):
        return self.client.remove_dataset_from_project(self.dataset_id, project_id)

    def rename(self, name):
        return self.client.rename_dataset(self.dataset_id, name)

    def delete(self):
        return self.client.delete_dataset(self.dataset_id)

    def wait_for_import(self, timeout=900):
        return self.client._poll(self, {'PENDING', 'IMPORTING'}, timeout=timeout)

    def wait_for_inspection(self, timeout=None):
        return self.client._poll(self, {'PENDING', 'UPLOADING', 'IMPORTING', 'CONVERTING', 'INSPECTING'}, timeout=timeout)

    def get_status(self):
        return self.describe().latest_dataset_version.status
